@@ -2,14 +2,19 @@
 from enum import IntEnum
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, TypedDict, Union, cast
 
-from zwave_js_server.const import CommandClass
-
+from ..const import CommandClass, INTERVIEW_FAILED
 from ..event import Event, EventBase
 from ..exceptions import FailedCommand, UnparseableValue, UnwriteableValue
 from .command_class import CommandClassInfo, CommandClassInfoDataType
 from .device_class import DeviceClass, DeviceClassDataType
 from .device_config import DeviceConfig, DeviceConfigDataType
 from .endpoint import Endpoint, EndpointDataType
+from .firmware import (
+    FirmwareUpdateFinished,
+    FirmwareUpdateFinishedDataType,
+    FirmwareUpdateProgress,
+    FirmwareUpdateProgressDataType,
+)
 from .notification import (
     EntryControlNotification,
     EntryControlNotificationDataType,
@@ -69,7 +74,7 @@ class NodeDataType(TypedDict, total=False):
     productId: int
     productType: int
     deviceConfig: DeviceConfigDataType
-    neighbors: List[int]
+    deviceDatabaseUrl: str
     keepAwake: bool
     index: int
     installerIcon: int
@@ -82,7 +87,7 @@ class NodeDataType(TypedDict, total=False):
     individualEndpointCount: int
     aggregatedEndpointCount: int
     interviewAttempts: int
-    interviewStage: int
+    interviewStage: Optional[Union[int, str]]
     commandClasses: List[CommandClassInfoDataType]
     values: List[ValueDataType]
 
@@ -95,6 +100,7 @@ class Node(EventBase):
         super().__init__()
         self.client = client
         self.data = data
+        self._device_config = DeviceConfig(self.data.get("deviceConfig", {}))
         self.values: Dict[str, Union[Value, ConfigurationValue]] = {}
         for val in data["values"]:
             value_id = _get_value_id_from_dict(self, val)
@@ -248,7 +254,7 @@ class Node(EventBase):
     @property
     def device_config(self) -> DeviceConfig:
         """Return the device_config."""
-        return DeviceConfig(self.data.get("deviceConfig", {}))
+        return self._device_config
 
     @property
     def label(self) -> Optional[str]:
@@ -256,9 +262,9 @@ class Node(EventBase):
         return self.data.get("label")
 
     @property
-    def neighbors(self) -> List[int]:
-        """Return the neighbors."""
-        return self.data.get("neighbors", [])
+    def device_database_url(self) -> Optional[str]:
+        """Return the device database URL."""
+        return self.data.get("deviceDatabaseUrl")
 
     @property
     def endpoints(self) -> List[Endpoint]:
@@ -291,10 +297,15 @@ class Node(EventBase):
         return self.data.get("interviewAttempts")
 
     @property
-    def interview_stage(self) -> Optional[int]:
+    def interview_stage(self) -> Optional[Union[int, str]]:
         """Return the interview_stage."""
         return self.data.get("interviewStage")
 
+    @property
+    def in_interview(self) -> bool:
+        """Return whether node is currently being interviewed."""
+        return not self.ready and self.interview_stage != INTERVIEW_FAILED
+
     @property
     def command_classes(self) -> List[CommandClassInfo]:
         """Return all CommandClasses supported on this node."""
@@ -383,6 +394,21 @@ class Node(EventBase):
         """Send refreshInfo command to Node."""
         await self.async_send_command("refresh_info", wait_for_result=False)
 
+    async def async_refresh_values(self) -> None:
+        """Send refreshValues command to Node."""
+        await self.async_send_command(
+            "refresh_values", wait_for_result=False, require_schema=4
+        )
+
+    async def async_refresh_cc_values(self, command_class: CommandClass) -> None:
+        """Send refreshCCValues command to Node."""
+        await self.async_send_command(
+            "refresh_cc_values",
+            commandClass=command_class,
+            wait_for_result=False,
+            require_schema=4,
+        )
+
     async def async_get_defined_value_ids(self) -> List[Value]:
         """Send getDefinedValueIDs command to Node."""
         data = await self.async_send_command(
@@ -419,6 +445,16 @@ class Node(EventBase):
             val = self.values[val]
         await self.async_send_command("poll_value", valueId=val.data, require_schema=1)
 
+    async def async_ping(self) -> bool:
+        """Send ping command to Node."""
+        data = (
+            await self.async_send_command(
+                "ping", require_schema=5, wait_for_result=True
+            )
+            or {}
+        )
+        return cast(bool, data.get("responded", False))
+
     def handle_wake_up(self, event: Event) -> None:
         """Process a node wake up event."""
         # pylint: disable=unused-argument
@@ -439,11 +475,25 @@ class Node(EventBase):
         # pylint: disable=unused-argument
         self.data["status"] = NodeStatus.ALIVE
 
-    def handle_interview_completed(self, event: Event) -> None:
-        """Process a node interview completed event."""
+    def handle_interview_started(self, event: Event) -> None:
+        """Process a node interview started event."""
+        # pylint: disable=unused-argument
+        self.data["ready"] = False
+        self.data["interviewStage"] = None
+
+    def handle_interview_stage_completed(self, event: Event) -> None:
+        """Process a node interview stage completed event."""
+        self.data["interviewStage"] = event.data["stageName"]
 
     def handle_interview_failed(self, event: Event) -> None:
         """Process a node interview failed event."""
+        # pylint: disable=unused-argument
+        self.data["interviewStage"] = INTERVIEW_FAILED
+
+    def handle_interview_completed(self, event: Event) -> None:
+        """Process a node interview completed event."""
+        # pylint: disable=unused-argument
+        self.data["ready"] = True
 
     def handle_ready(self, event: Event) -> None:
         """Process a node ready event."""
@@ -486,7 +536,9 @@ class Node(EventBase):
         # in the event, otherwise use the event data
         event_data = event.data["args"]
         if value := self.values.get(_get_value_id_from_dict(self, event_data)):
-            value_notification = ValueNotification(self, value.data)
+            value_notification = ValueNotification(
+                self, cast(ValueDataType, dict(value.data))
+            )
             value_notification.update(event_data)
         else:
             value_notification = ValueNotification(self, event_data)
@@ -512,6 +564,12 @@ class Node(EventBase):
 
     def handle_firmware_update_progress(self, event: Event) -> None:
         """Process a node firmware update progress event."""
+        event.data["firmware_update_progress"] = FirmwareUpdateProgress(
+            self, cast(FirmwareUpdateProgressDataType, event.data)
+        )
 
     def handle_firmware_update_finished(self, event: Event) -> None:
         """Process a node firmware update finished event."""
+        event.data["firmware_update_finished"] = FirmwareUpdateFinished(
+            self, cast(FirmwareUpdateFinishedDataType, event.data)
+        )
